@@ -52,16 +52,19 @@ class invoiceOperator extends entityDatabaseOperator{
         return null;
     }
 
-    public function getChargeable($limit)
+    public function getChargeable($limit, $userId=null)
     {
-        return $this->vault
+        $query = $this->vault
             ->select($this->dbTable)
             ->fields()
             ->where('paid', 0)
             ->where('abandoned', 0)
             ->where('on_hold', 0)
-            ->where('billing_enabled', 1)
-            ->orderBy('last_payment_attempt', 'ASC')
+            ->where('billing_enabled', 1);
+        if ($userId) {
+            $query->where('user_id', $userId);
+        }
+        return $query->orderBy('last_payment_attempt', 'ASC')
             ->limit($limit)
             ->execute()
             ->fetchAll();
